/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.elasticmapreduce.model;

import java.io.Serializable;
import com.amazonaws.AmazonWebServiceRequest;

/**
 * <p>
 * This input determines which step to describe.
 * </p>
 */
public class DescribeStepRequest extends AmazonWebServiceRequest implements
        Serializable, Cloneable {

    /**
     * <p>
     * The identifier of the cluster with steps to describe.
     * </p>
     */
    private String clusterId;
    /**
     * <p>
     * The identifier of the step to describe.
     * </p>
     */
    private String stepId;

    /**
     * <p>
     * The identifier of the cluster with steps to describe.
     * </p>
     * 
     * @param clusterId
     *        The identifier of the cluster with steps to describe.
     */

    public void setClusterId(String clusterId) {
        this.clusterId = clusterId;
    }

    /**
     * <p>
     * The identifier of the cluster with steps to describe.
     * </p>
     * 
     * @return The identifier of the cluster with steps to describe.
     */

    public String getClusterId() {
        return this.clusterId;
    }

    /**
     * <p>
     * The identifier of the cluster with steps to describe.
     * </p>
     * 
     * @param clusterId
     *        The identifier of the cluster with steps to describe.
     * @return Returns a reference to this object so that method calls can be
     *         chained together.
     */

    public DescribeStepRequest withClusterId(String clusterId) {
        setClusterId(clusterId);
        return this;
    }

    /**
     * <p>
     * The identifier of the step to describe.
     * </p>
     * 
     * @param stepId
     *        The identifier of the step to describe.
     */

    public void setStepId(String stepId) {
        this.stepId = stepId;
    }

    /**
     * <p>
     * The identifier of the step to describe.
     * </p>
     * 
     * @return The identifier of the step to describe.
     */

    public String getStepId() {
        return this.stepId;
    }

    /**
     * <p>
     * The identifier of the step to describe.
     * </p>
     * 
     * @param stepId
     *        The identifier of the step to describe.
     * @return Returns a reference to this object so that method calls can be
     *         chained together.
     */

    public DescribeStepRequest withStepId(String stepId) {
        setStepId(stepId);
        return this;
    }

    /**
     * Returns a string representation of this object; useful for testing and
     * debugging.
     *
     * @return A string representation of this object.
     *
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");
        if (getClusterId() != null)
            sb.append("ClusterId: " + getClusterId() + ",");
        if (getStepId() != null)
            sb.append("StepId: " + getStepId());
        sb.append("}");
        return sb.toString();
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;

        if (obj instanceof DescribeStepRequest == false)
            return false;
        DescribeStepRequest other = (DescribeStepRequest) obj;
        if (other.getClusterId() == null ^ this.getClusterId() == null)
            return false;
        if (other.getClusterId() != null
                && other.getClusterId().equals(this.getClusterId()) == false)
            return false;
        if (other.getStepId() == null ^ this.getStepId() == null)
            return false;
        if (other.getStepId() != null
                && other.getStepId().equals(this.getStepId()) == false)
            return false;
        return true;
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int hashCode = 1;

        hashCode = prime * hashCode
                + ((getClusterId() == null) ? 0 : getClusterId().hashCode());
        hashCode = prime * hashCode
                + ((getStepId() == null) ? 0 : getStepId().hashCode());
        return hashCode;
    }

    @Override
    public DescribeStepRequest clone() {
        return (DescribeStepRequest) super.clone();
    }
}